@@ -4,6 +4,10 @@ import os
 import io
 import sys
 import pkgutil
+
+import pkg_resources  # part of setuptools
+version = pkg_resources.require("pbn2html")[0].version
+
 if "pbn2html" in os.environ.get("_"):
     from .pbn_parser import importPBN
 else:
@@ -20,6 +24,10 @@ html_template="""
     <meta name="Generator" content="pbn2html toolkit">
     <title>Enjoy the bridge game</title>
   </head>
+  <h2>Introduction</h2>
+  <p>this is designed to be used (copy/paste) for Microsoft Word (Chinese) directly</p>
+  <p>Designed by Larry Cai and produced by <a href="https://pypi.org/project/pbn2html/">pbn2html</a>, version $version</p>
+  <p>Credit to <a href="https://bridgecomposer.com/">BridgeComposer Version 5.83 (64 bit)</a></p>
   <body class=bcbody>
     <!-- Credit to BridgeComposer Version 5.83 (64 bit) - https://bridgecomposer.com/ -->
     <div class=bcboard style="text-align: center">
@@ -50,7 +58,7 @@ card_template="""
 """
 
 board_template="""
-              <table class=bcct style="width: 4em; height: 4em; border-collapse: collapse; font: 10pt @微软雅黑, sans-serif; color: #ffffff; border: 1px solid #aaaaaa">
+              <table class=bcct style="width: 4em; height: 4em; border-collapse: collapse; font: 10pt simsun, sans-serif; color: #ffffff; border: 1px solid #aaaaaa">
                 <tr class=bcct1>
                   <td class=bcct1 style="text-align: center; vertical-align: text-top; padding: 1px"></td>
                   <td class=bcct1 style="text-align: center; vertical-align: text-top; padding: 1px;background-color: $ns_vulnerable;">北</td>
@@ -90,8 +98,8 @@ def html_board(vulnerable, dealer):
     arrows={"S": "&darr;","W": "&larr;","N": "&uarr;","E": "&rarr;"}
     src = Template(board_template)
     
-    NONE_COLOR="green"
-    VULNERABLE_COLOR="red"
+    NONE_COLOR="#93C47D"
+    VULNERABLE_COLOR="#E06666"
 
     all = {}
     if vulnerable == "NS":
@@ -189,7 +197,7 @@ def pbn2html(pbn_file):
     all = {
         "generated" : "2020-12-01"
     }
-    
+
     # handle multiple pbn in one file
     pbnstr = open(pbn_file,encoding="utf-8" ).read()
     delimiter="[Event"
@@ -220,13 +228,79 @@ def pbn2html(pbn_file):
         result += src.safe_substitute(all)
         #print(len(result))
     src = Template(html_template)
-    all = { "all": result }
+    all = { "all": result, "version": version }
     result = src.safe_substitute(all)
     output = os.path.splitext(pbn_file)[0]+'.html'
     with io.open(output, "w", encoding="utf-8") as text_file:
         print("write to file %s" % output)
         text_file.write(result)
 
+def get_from_pbn(pbn):
+    tags, hands, section_auction = importPBN(pbn)
+    pbn = {
+        "tags": tags,
+        "hands": hands,
+        "section_auction" : section_auction
+    }
+    return pbn
+
+def get_from_pbn_file(pbn_file):
+    pbn = open(pbn_file,encoding="utf-8" ).read()
+    return get_from_pbn(pbn)
+
+def pbn_html_auction(pbn):
+    all = {}
+    tags = pbn["tags"]
+    section_auction = pbn["section_auction"]
+    all["auction"] = html_auction(tags["Auction"], section_auction)
+    if "pbn2html" in os.environ.get("_"):
+        template = pkgutil.get_data(__name__,'auction_template.html')
+        src = Template(template.decode('utf-8'))
+    else:
+        template = open("auction_template.html", "r",encoding="utf-8").read()
+        src = Template(template)
+    result = src.safe_substitute(all)
+    return result
+
+def pbn_html_deal(pbn):
+    all = {}
+    tags = pbn["tags"]
+    hands = pbn["hands"]
+    all["north"] = html_card(hands["N"])
+    all["west"] = html_card(hands["W"])
+    all["east"] = html_card(hands["E"])
+    all["south"] = html_card(hands["S"])
+    all["board"] = html_board(tags["Vulnerable"],tags["Dealer"])
+    all["extra"] = html_extra(tags["Contract"],tags["Declarer"])
+    if "pbn2html" in os.environ.get("_"):
+        template = pkgutil.get_data(__name__,'deal_template.html')
+        src = Template(template.decode('utf-8'))
+    else:
+        template = open("deal_template.html", "r",encoding="utf-8").read()
+        src = Template(template)
+    result = src.safe_substitute(all)
+    return result
+
+def pbn_html_all(pbn):
+    all = {}
+    tags = pbn["tags"]
+    hands = pbn["hands"]
+    section_auction = pbn["section_auction"]
+    all["north"] = html_card(hands["N"])
+    all["west"] = html_card(hands["W"])
+    all["east"] = html_card(hands["E"])
+    all["south"] = html_card(hands["S"])
+    all["board"] = html_board(tags["Vulnerable"],tags["Dealer"])
+    all["extra"] = html_extra(tags["Contract"],tags["Declarer"])
+    all["auction"] = html_auction(tags["Auction"], section_auction)
+    if "pbn2html" in os.environ.get("_"):
+        template = pkgutil.get_data(__name__,'all_template.html')
+        src = Template(template.decode('utf-8'))
+    else:
+        template = open("all_template.html", "r",encoding="utf-8").read()
+        src = Template(template)
+    result = src.safe_substitute(all)
+    return result
 
 def main():
     # print(sys.argv)
@@ -234,6 +308,10 @@ def main():
         param = sys.argv[1:]
         if param[0].endswith(".pbn"):
             pbn2html(param[0])
+            #pbn = get_from_pbn_file(param[0])
+            #print(pbn_html_all(pbn))
+            #print(pbn_html_auction(pbn))
+            #print(pbn_html_deal(pbn))
         else:
             print("pbn2html.py <file.pbn>")
     else:
